.\" Copyright (c) 1990 Carnegie Mellon University
.\" All Rights Reserved.
.\" 
.\" Permission to use, copy, modify and distribute this software and its
.\" documentation is hereby granted, provided that both the copyright
.\" notice and this permission notice appear in all copies of the
.\" software, derivative works or modified versions, and any portions
.\" thereof, and that both notices appear in supporting documentation.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND CARNEGIE MELLON UNIVERSITY
.\" DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.  IN NO EVENT
.\" SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR ANY SPECIAL, DIRECT,
.\" INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
.\" RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
.\" CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
.\"
.\" Users of this software agree to return to Carnegie Mellon any
.\" improvements or extensions that they make and grant Carnegie the
.\" rights to redistribute these changes.
.\"
.\" Export of this software is permitted only after complying with the
.\" regulations of the U.S. Deptartment of Commerce relating to the
.\" Export of Technical Data.
.\" 
.TH CONCAT 3 2/22/89
.AT 3
.SH NAME
concat, vconcat \- concatenate strings into a buffer
.\""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
.\" HISTORY
.\" $Log:	concat.3,v $
.\" Revision 2.3  90/12/12  15:47:26  mja
.\" 	Add copyright/disclaimer for distribution.
.\" 
.\" Revision 2.2  89/02/22  17:58:48  gm0w
.\" 	Created.
.\" 	[89/02/22            gm0w]
.\" 
.\""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
.SH SYNOPSIS
.nf
.B
char *concat(buf, buflen, str1, str2, ..., NULL);
.br
.B
char *buf;
.br
.B
int buflen;
.br
.B
char *str1, *str2, ...;
.PP
.B
#include <varargs.h>
.PP
.B
char *vconcat(buf, buflen, ap)
.br
.B
char *buf;
.br
.B
int buflen;
.br
.B
va_list ap;
.SH DESCRIPTION
.I Concat
takes a list of string pointers and concatenates them into a buffer.
The string pointers are terminated by a NULL (0) string pointer.
.I Buf
should be a buffer of length
.IR buflen
that will contain the concatenation of the string pointers.
.PP
.I Concat
will return NULL if
.I buf
is NULL, if
.I buflen
is <= 0, or if the concatenation of the string pointers did not
fit into
.IR buf .
In all other cases,
.I concat
will terminate the concatenation with a null (0) byte and return a
pointer to the null byte.
.PP
.I Vconcat
is a varargs version of concat which may be used by routines to
concatenate their string pointer argument list into a buffer.
.SH EXAMPLES
.PP
.I end
=
.IR concat ( buf ,
.IR buflen ,
.IR dir ,
\fI"/"\fR,
.IR file ,
.IR NULL );
.PP
could be used to generate a file path from a directory name and a
file name, returning a pointer to the end of the path.
.PP
.IR concat ( end ,
.IR buf + buflen - end ,
\fI"."\fR,
.IR ext ,
.IR NULL );
.PP
could then be used to add an extension to the file path.
.SH "SEE ALSO"
strcat(3), strcpy(3), sprintf(3)
